import TreeContainer from './Base';
import TreeIterator from './Base/TreeIterator';
import { initContainer } from "../ContainerBase";
declare class OrderedSetIterator<K> extends TreeIterator<K, undefined> {
    get pointer(): K;
    copy(): OrderedSetIterator<K>;
}
export type { OrderedSetIterator };
declare class OrderedSet<K> extends TreeContainer<K, undefined> {
    /**
     * @param container The initialization container.
     * @param cmp The compare function.
     * @param enableIndex Whether to enable iterator indexing function.
     * @example
     * new OrderedSet();
     * new OrderedSet([0, 1, 2]);
     * new OrderedSet([0, 1, 2], (x, y) => x - y);
     * new OrderedSet([0, 1, 2], (x, y) => x - y, true);
     */
    constructor(container?: initContainer<K>, cmp?: (x: K, y: K) => number, enableIndex?: boolean);
    begin(): OrderedSetIterator<K>;
    end(): OrderedSetIterator<K>;
    rBegin(): OrderedSetIterator<K>;
    rEnd(): OrderedSetIterator<K>;
    front(): K | undefined;
    back(): K | undefined;
    forEach(callback: (element: K, index: number, set: OrderedSet<K>) => void): void;
    getElementByPos(pos: number): K;
    /**
     * @description Insert element to set.
     * @param key The key want to insert.
     * @param hint You can give an iterator hint to improve insertion efficiency.
     * @example
     * const st = new OrderedSet([2, 4, 5]);
     * const iter = st.begin();
     * st.insert(1);
     * st.insert(3, iter);  // give a hint will be faster.
     */
    insert(key: K, hint?: OrderedSetIterator<K>): void;
    find(element: K): OrderedSetIterator<K>;
    lowerBound(key: K): OrderedSetIterator<K>;
    upperBound(key: K): OrderedSetIterator<K>;
    reverseLowerBound(key: K): OrderedSetIterator<K>;
    reverseUpperBound(key: K): OrderedSetIterator<K>;
    union(other: OrderedSet<K>): void;
    [Symbol.iterator](): Generator<K, void, undefined>;
}
export default OrderedSet;
